#
# PySNMP MIB module EtherLike-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/EtherLike-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:11:58 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( ifIndex, InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex", "InterfaceIndex")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( transmission, iso, Counter64, ModuleIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, IpAddress, mib_2, TimeTicks, ObjectIdentity, Gauge32, Counter32, NotificationType, MibIdentifier, Integer32, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "transmission", "iso", "Counter64", "ModuleIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "IpAddress", "mib-2", "TimeTicks", "ObjectIdentity", "Gauge32", "Counter32", "NotificationType", "MibIdentifier", "Integer32", "Bits")
( TextualConvention, DisplayString, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TruthValue")
etherMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 35)).setRevisions(("2003-09-19 00:00", "1999-08-24 04:00", "1998-06-03 21:50", "1994-02-03 04:00",))
if mibBuilder.loadTexts: etherMIB.setLastUpdated('200309190000Z')
if mibBuilder.loadTexts: etherMIB.setOrganization('IETF Ethernet Interfaces and Hub MIB\n                        Working Group')
if mibBuilder.loadTexts: etherMIB.setContactInfo('WG E-mail: hubmib@ietf.org\n             To subscribe: hubmib-request@ietf.org\n\n                    Chair: Dan Romascanu\n                   Postal: Avaya Inc.\n                           Atidum Technology Park, Bldg. 3\n                           Tel Aviv 61131\n                           Israel\n                      Tel: +972 3 645 8414\n                   E-mail: dromasca@avaya.com\n\n                  Editor: John Flick\n                  Postal: Hewlett-Packard Company\n                          8000 Foothills Blvd. M/S 5557\n                          Roseville, CA 95747-5557\n                          USA\n                     Tel: +1 916 785 4018\n                     Fax: +1 916 785 1199\n                  E-mail: johnf@rose.hp.com')
if mibBuilder.loadTexts: etherMIB.setDescription("The MIB module to describe generic objects for\n                       ethernet-like network interfaces.\n\n                       The following reference is used throughout this\n                       MIB module:\n\n                       [IEEE 802.3 Std] refers to:\n                          IEEE Std 802.3, 2002 Edition: 'IEEE Standard\n                          for Information technology -\n                          Telecommunications and information exchange\n                          between systems - Local and metropolitan\n                          area networks - Specific requirements -\n                          Part 3: Carrier sense multiple access with\n                          collision detection (CSMA/CD) access method\n                          and physical layer specifications', as\n                          amended by IEEE Std 802.3ae-2002:\n                          'Amendment: Media Access Control (MAC)\n                          Parameters, Physical Layer, and Management\n                          Parameters for 10 Gb/s Operation', August,\n                          2002.\n\n                       Of particular interest is Clause 30, '10 Mb/s,\n                       100 Mb/s, 1000 Mb/s, and 10 Gb/s Management'.\n\n                       Copyright (C) The Internet Society (2003).  This\n                       version of this MIB module is part of RFC 3635;\n                       see the RFC itself for full legal notices.")
etherMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 35, 1))
dot3 = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7))
dot3StatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 7, 2), )
if mibBuilder.loadTexts: dot3StatsTable.setDescription('Statistics for a collection of ethernet-like\n                       interfaces attached to a particular system.\n                       There will be one row in this table for each\n                       ethernet-like interface in the system.')
dot3StatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 7, 2, 1), ).setIndexNames((0, "EtherLike-MIB", "dot3StatsIndex"))
if mibBuilder.loadTexts: dot3StatsEntry.setDescription('Statistics for a particular interface to an\n                       ethernet-like medium.')
dot3StatsIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsIndex.setDescription('An index value that uniquely identifies an\n                       interface to an ethernet-like medium.  The\n                       interface identified by a particular value of\n                       this index is the same interface as identified\n                       by the same value of ifIndex.')
dot3StatsAlignmentErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsAlignmentErrors.setDescription("A count of frames received on a particular\n                       interface that are not an integral number of\n                       octets in length and do not pass the FCS check.\n\n                       The count represented by an instance of this\n                       object is incremented when the alignmentError\n                       status is returned by the MAC service to the\n                       LLC (or other MAC user). Received frames for\n                       which multiple error conditions pertain are,\n                       according to the conventions of IEEE 802.3\n                       Layer Management, counted exclusively according\n                       to the error status presented to the LLC.\n\n                       This counter does not increment for group\n                       encoding schemes greater than 4 bits per group.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCStatsAlignmentErrors object for 10 Gb/s\n                       or faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3StatsFCSErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsFCSErrors.setDescription("A count of frames received on a particular\n                       interface that are an integral number of octets\n                       in length but do not pass the FCS check.  This\n                       count does not include frames received with\n                       frame-too-long or frame-too-short error.\n\n                       The count represented by an instance of this\n                       object is incremented when the frameCheckError\n                       status is returned by the MAC service to the\n                       LLC (or other MAC user). Received frames for\n                       which multiple error conditions pertain are,\n                       according to the conventions of IEEE 802.3\n                       Layer Management, counted exclusively according\n                       to the error status presented to the LLC.\n\n                       Note:  Coding errors detected by the physical\n                       layer for speeds above 10 Mb/s will cause the\n                       frame to fail the FCS check.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCStatsFCSErrors object for 10 Gb/s or\n                       faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3StatsSingleCollisionFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsSingleCollisionFrames.setDescription('A count of frames that are involved in a single\n                       collision, and are subsequently transmitted\n                       successfully.\n\n                       A frame that is counted by an instance of this\n                       object is also counted by the corresponding\n                       instance of either the ifOutUcastPkts,\n                       ifOutMulticastPkts, or ifOutBroadcastPkts,\n                       and is not counted by the corresponding\n                       instance of the dot3StatsMultipleCollisionFrames\n                       object.\n\n                       This counter does not increment when the\n                       interface is operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3StatsMultipleCollisionFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsMultipleCollisionFrames.setDescription('A count of frames that are involved in more\n                       than one collision and are subsequently\n                       transmitted successfully.\n\n                       A frame that is counted by an instance of this\n                       object is also counted by the corresponding\n                       instance of either the ifOutUcastPkts,\n                       ifOutMulticastPkts, or ifOutBroadcastPkts,\n                       and is not counted by the corresponding\n                       instance of the dot3StatsSingleCollisionFrames\n                       object.\n\n                       This counter does not increment when the\n                       interface is operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3StatsSQETestErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsSQETestErrors.setDescription('A count of times that the SQE TEST ERROR\n                       is received on a particular interface. The\n                       SQE TEST ERROR is set in accordance with the\n                       rules for verification of the SQE detection\n                       mechanism in the PLS Carrier Sense Function as\n                       described in IEEE Std. 802.3, 2000 Edition,\n                       section 7.2.4.6.\n\n                       This counter does not increment on interfaces\n                       operating at speeds greater than 10 Mb/s, or on\n                       interfaces operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3StatsDeferredTransmissions = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsDeferredTransmissions.setDescription('A count of frames for which the first\n                       transmission attempt on a particular interface\n                       is delayed because the medium is busy.\n\n                       The count represented by an instance of this\n                       object does not include frames involved in\n                       collisions.\n\n                       This counter does not increment when the\n                       interface is operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3StatsLateCollisions = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsLateCollisions.setDescription('The number of times that a collision is\n                       detected on a particular interface later than\n                       one slotTime into the transmission of a packet.\n\n                       A (late) collision included in a count\n                       represented by an instance of this object is\n                       also considered as a (generic) collision for\n                       purposes of other collision-related\n                       statistics.\n\n                       This counter does not increment when the\n                       interface is operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3StatsExcessiveCollisions = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsExcessiveCollisions.setDescription('A count of frames for which transmission on a\n                       particular interface fails due to excessive\n                       collisions.\n\n                       This counter does not increment when the\n                       interface is operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3StatsInternalMacTransmitErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsInternalMacTransmitErrors.setDescription("A count of frames for which transmission on a\n                       particular interface fails due to an internal\n                       MAC sublayer transmit error. A frame is only\n                       counted by an instance of this object if it is\n                       not counted by the corresponding instance of\n                       either the dot3StatsLateCollisions object, the\n                       dot3StatsExcessiveCollisions object, or the\n                       dot3StatsCarrierSenseErrors object.\n\n                       The precise meaning of the count represented by\n                       an instance of this object is implementation-\n                       specific.  In particular, an instance of this\n                       object may represent a count of transmission\n                       errors on a particular interface that are not\n                       otherwise counted.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCStatsInternalMacTransmitErrors object for\n                       10 Gb/s or faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3StatsCarrierSenseErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsCarrierSenseErrors.setDescription('The number of times that the carrier sense\n                       condition was lost or never asserted when\n                       attempting to transmit a frame on a particular\n                       interface.\n\n                       The count represented by an instance of this\n                       object is incremented at most once per\n                       transmission attempt, even if the carrier sense\n                       condition fluctuates during a transmission\n                       attempt.\n\n                       This counter does not increment when the\n                       interface is operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3StatsFrameTooLongs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsFrameTooLongs.setDescription("A count of frames received on a particular\n                       interface that exceed the maximum permitted\n                       frame size.\n\n                       The count represented by an instance of this\n                       object is incremented when the frameTooLong\n                       status is returned by the MAC service to the\n                       LLC (or other MAC user). Received frames for\n                       which multiple error conditions pertain are,\n                       according to the conventions of IEEE 802.3\n                       Layer Management, counted exclusively according\n                       to the error status presented to the LLC.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 80 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCStatsFrameTooLongs object for 10 Gb/s\n                       or faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3StatsInternalMacReceiveErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsInternalMacReceiveErrors.setDescription("A count of frames for which reception on a\n                       particular interface fails due to an internal\n                       MAC sublayer receive error. A frame is only\n                       counted by an instance of this object if it is\n                       not counted by the corresponding instance of\n                       either the dot3StatsFrameTooLongs object, the\n                       dot3StatsAlignmentErrors object, or the\n                       dot3StatsFCSErrors object.\n\n                       The precise meaning of the count represented by\n                       an instance of this object is implementation-\n                       specific.  In particular, an instance of this\n                       object may represent a count of receive errors\n                       on a particular interface that are not\n                       otherwise counted.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCStatsInternalMacReceiveErrors object for\n                       10 Gb/s or faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3StatsEtherChipSet = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 17), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsEtherChipSet.setDescription('******** THIS OBJECT IS DEPRECATED ********\n\n                       This object contains an OBJECT IDENTIFIER\n                       which identifies the chipset used to\n                       realize the interface. Ethernet-like\n                       interfaces are typically built out of\n                       several different chips. The MIB implementor\n                       is presented with a decision of which chip\n                       to identify via this object. The implementor\n                       should identify the chip which is usually\n                       called the Medium Access Control chip.\n                       If no such chip is easily identifiable,\n                       the implementor should identify the chip\n                       which actually gathers the transmit\n                       and receive statistics and error\n                       indications. This would allow a\n                       manager station to correlate the\n                       statistics and the chip generating\n                       them, giving it the ability to take\n                       into account any known anomalies\n                       in the chip.\n\n                       This object has been deprecated.  Implementation\n                       feedback indicates that it is of limited use for\n                       debugging network problems in the field, and\n                       the administrative overhead involved in\n                       maintaining a registry of chipset OIDs is not\n                       justified.')
dot3StatsSymbolErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsSymbolErrors.setDescription("For an interface operating at 100 Mb/s, the\n                       number of times there was an invalid data symbol\n                       when a valid carrier was present.\n\n                       For an interface operating in half-duplex mode\n                       at 1000 Mb/s, the number of times the receiving\n                       media is non-idle (a carrier event) for a period\n                       of time equal to or greater than slotTime, and\n                       during which there was at least one occurrence\n                       of an event that causes the PHY to indicate\n                       'Data reception error' or 'carrier extend error'\n                       on the GMII.\n\n                       For an interface operating in full-duplex mode\n                       at 1000 Mb/s, the number of times the receiving\n                       media is non-idle (a carrier event) for a period\n                       of time equal to or greater than minFrameSize,\n                       and during which there was at least one\n                       occurrence of an event that causes the PHY to\n                       indicate 'Data reception error' on the GMII.\n\n                       For an interface operating at 10 Gb/s, the\n                       number of times the receiving media is non-idle\n                       (a carrier event) for a period of time equal to\n                       or greater than minFrameSize, and during which\n                       there was at least one occurrence of an event\n                       that causes the PHY to indicate 'Receive Error'\n                       on the XGMII.\n\n                       The count represented by an instance of this\n                       object is incremented at most once per carrier\n                       event, even if multiple symbol errors occur\n                       during the carrier event.  This count does\n                       not increment if a collision is present.\n\n                       This counter does not increment when the\n                       interface is operating at 10 Mb/s.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCStatsSymbolErrors object for 10 Gb/s\n                       or faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3StatsDuplexStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 19), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("halfDuplex", 2), ("fullDuplex", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsDuplexStatus.setDescription("The current mode of operation of the MAC\n                       entity.  'unknown' indicates that the current\n                       duplex mode could not be determined.\n\n                       Management control of the duplex mode is\n                       accomplished through the MAU MIB.  When\n                       an interface does not support autonegotiation,\n                       or when autonegotiation is not enabled, the\n                       duplex mode is controlled using\n                       ifMauDefaultType.  When autonegotiation is\n                       supported and enabled, duplex mode is controlled\n                       using ifMauAutoNegAdvertisedBits.  In either\n                       case, the currently operating duplex mode is\n                       reflected both in this object and in ifMauType.\n\n                       Note that this object provides redundant\n                       information with ifMauType.  Normally, redundant\n                       objects are discouraged.  However, in this\n                       instance, it allows a management application to\n                       determine the duplex status of an interface\n                       without having to know every possible value of\n                       ifMauType.  This was felt to be sufficiently\n                       valuable to justify the redundancy.")
dot3StatsRateControlAbility = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 20), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsRateControlAbility.setDescription("'true' for interfaces operating at speeds above\n                       1000 Mb/s that support Rate Control through\n                       lowering the average data rate of the MAC\n                       sublayer, with frame granularity, and 'false'\n                       otherwise.")
dot3StatsRateControlStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 2, 1, 21), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("rateControlOff", 1), ("rateControlOn", 2), ("unknown", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3StatsRateControlStatus.setDescription('The current Rate Control mode of operation of\n                       the MAC sublayer of this interface.')
dot3CollTable = MibTable((1, 3, 6, 1, 2, 1, 10, 7, 5), )
if mibBuilder.loadTexts: dot3CollTable.setDescription('A collection of collision histograms for a\n                       particular set of interfaces.')
dot3CollEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 7, 5, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "EtherLike-MIB", "dot3CollCount"))
if mibBuilder.loadTexts: dot3CollEntry.setDescription('A cell in the histogram of per-frame\n                       collisions for a particular interface.  An\n                       instance of this object represents the\n                       frequency of individual MAC frames for which\n                       the transmission (successful or otherwise) on a\n                       particular interface is accompanied by a\n                       particular number of media collisions.')
dot3CollCount = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 5, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,16)))
if mibBuilder.loadTexts: dot3CollCount.setDescription('The number of per-frame media collisions for\n                       which a particular collision histogram cell\n                       represents the frequency on a particular\n                       interface.')
dot3CollFrequencies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 5, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3CollFrequencies.setDescription('A count of individual MAC frames for which the\n                       transmission (successful or otherwise) on a\n                       particular interface occurs after the\n                       frame has experienced exactly the number\n                       of collisions in the associated\n                       dot3CollCount object.\n\n                       For example, a frame which is transmitted\n                       on interface 77 after experiencing\n                       exactly 4 collisions would be indicated\n                       by incrementing only dot3CollFrequencies.77.4.\n                       No other instance of dot3CollFrequencies would\n                       be incremented in this example.\n\n                       This counter does not increment when the\n                       interface is operating in full-duplex mode.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3ControlTable = MibTable((1, 3, 6, 1, 2, 1, 10, 7, 9), )
if mibBuilder.loadTexts: dot3ControlTable.setDescription('A table of descriptive and status information\n                       about the MAC Control sublayer on the\n                       ethernet-like interfaces attached to a\n                       particular system.  There will be one row in\n                       this table for each ethernet-like interface in\n                       the system which implements the MAC Control\n                       sublayer.  If some, but not all, of the\n                       ethernet-like interfaces in the system implement\n                       the MAC Control sublayer, there will be fewer\n                       rows in this table than in the dot3StatsTable.')
dot3ControlEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 7, 9, 1), ).setIndexNames((0, "EtherLike-MIB", "dot3StatsIndex"))
if mibBuilder.loadTexts: dot3ControlEntry.setDescription('An entry in the table, containing information\n                       about the MAC Control sublayer on a single\n                       ethernet-like interface.')
dot3ControlFunctionsSupported = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 9, 1, 1), Bits().clone(namedValues=NamedValues(("pause", 0),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3ControlFunctionsSupported.setDescription('A list of the possible MAC Control functions\n                       implemented for this interface.')
dot3ControlInUnknownOpcodes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 9, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3ControlInUnknownOpcodes.setDescription("A count of MAC Control frames received on this\n                       interface that contain an opcode that is not\n                       supported by this device.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCControlInUnknownOpcodes object for 10 Gb/s\n                       or faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3HCControlInUnknownOpcodes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 9, 1, 3), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCControlInUnknownOpcodes.setDescription('A count of MAC Control frames received on this\n                       interface that contain an opcode that is not\n                       supported by this device.\n\n                       This counter is a 64 bit version of\n                       dot3ControlInUnknownOpcodes.  It should be used\n                       on interfaces operating at 10 Gb/s or faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3PauseTable = MibTable((1, 3, 6, 1, 2, 1, 10, 7, 10), )
if mibBuilder.loadTexts: dot3PauseTable.setDescription("A table of descriptive and status information\n                       about the MAC Control PAUSE function on the\n                       ethernet-like interfaces attached to a\n                       particular system. There will be one row in\n                       this table for each ethernet-like interface in\n                       the system which supports the MAC Control PAUSE\n                       function (i.e., the 'pause' bit in the\n                       corresponding instance of\n                       dot3ControlFunctionsSupported is set).  If some,\n                       but not all, of the ethernet-like interfaces in\n                       the system implement the MAC Control PAUSE\n                       function (for example, if some interfaces only\n                       support half-duplex), there will be fewer rows\n                       in this table than in the dot3StatsTable.")
dot3PauseEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 7, 10, 1), ).setIndexNames((0, "EtherLike-MIB", "dot3StatsIndex"))
if mibBuilder.loadTexts: dot3PauseEntry.setDescription('An entry in the table, containing information\n                       about the MAC Control PAUSE function on a single\n                       ethernet-like interface.')
dot3PauseAdminMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 10, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("disabled", 1), ("enabledXmit", 2), ("enabledRcv", 3), ("enabledXmitAndRcv", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot3PauseAdminMode.setDescription("This object is used to configure the default\n                       administrative PAUSE mode for this interface.\n\n                       This object represents the\n                       administratively-configured PAUSE mode for this\n                       interface.  If auto-negotiation is not enabled\n                       or is not implemented for the active MAU\n                       attached to this interface, the value of this\n                       object determines the operational PAUSE mode\n                       of the interface whenever it is operating in\n                       full-duplex mode.  In this case, a set to this\n                       object will force the interface into the\n                       specified mode.\n\n                       If auto-negotiation is implemented and enabled\n                       for the MAU attached to this interface, the\n                       PAUSE mode for this interface is determined by\n                       auto-negotiation, and the value of this object\n                       denotes the mode to which the interface will\n                       automatically revert if/when auto-negotiation is\n                       later disabled.  Note that when auto-negotiation\n                       is running, administrative control of the PAUSE\n                       mode may be accomplished using the\n                       ifMauAutoNegCapAdvertisedBits object in the\n                       MAU-MIB.\n\n                       Note that the value of this object is ignored\n                       when the interface is not operating in\n                       full-duplex mode.\n\n                       An attempt to set this object to\n                       'enabledXmit(2)' or 'enabledRcv(3)' will fail\n                       on interfaces that do not support operation\n                       at greater than 100 Mb/s.")
dot3PauseOperMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 10, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("disabled", 1), ("enabledXmit", 2), ("enabledRcv", 3), ("enabledXmitAndRcv", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3PauseOperMode.setDescription("This object reflects the PAUSE mode currently\n                       in use on this interface, as determined by\n                       either (1) the result of the auto-negotiation\n                       function or (2) if auto-negotiation is not\n                       enabled or is not implemented for the active MAU\n                       attached to this interface, by the value of\n                       dot3PauseAdminMode.  Interfaces operating at\n                       100 Mb/s or less will never return\n                       'enabledXmit(2)' or 'enabledRcv(3)'.  Interfaces\n                       operating in half-duplex mode will always return\n                       'disabled(1)'.  Interfaces on which\n                       auto-negotiation is enabled but not yet\n                       completed should return the value\n                       'disabled(1)'.")
dot3InPauseFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 10, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3InPauseFrames.setDescription("A count of MAC Control frames received on this\n                       interface with an opcode indicating the PAUSE\n                       operation.\n\n                       This counter does not increment when the\n                       interface is operating in half-duplex mode.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCInPauseFrames object for 10 Gb/s or\n                       faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3OutPauseFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 10, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3OutPauseFrames.setDescription("A count of MAC Control frames transmitted on\n                       this interface with an opcode indicating the\n                       PAUSE operation.\n\n                       This counter does not increment when the\n                       interface is operating in half-duplex mode.\n\n                       For interfaces operating at 10 Gb/s, this\n                       counter can roll over in less than 5 minutes if\n                       it is incrementing at its maximum rate.  Since\n                       that amount of time could be less than a\n                       management station's poll cycle time, in order\n                       to avoid a loss of information, a management\n                       station is advised to poll the\n                       dot3HCOutPauseFrames object for 10 Gb/s or\n                       faster interfaces.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3HCInPauseFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 10, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCInPauseFrames.setDescription('A count of MAC Control frames received on this\n                       interface with an opcode indicating the PAUSE\n                       operation.\n\n                       This counter does not increment when the\n                       interface is operating in half-duplex mode.\n\n                       This counter is a 64 bit version of\n                       dot3InPauseFrames.  It should be used on\n                       interfaces operating at 10 Gb/s or faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3HCOutPauseFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 10, 1, 6), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCOutPauseFrames.setDescription('A count of MAC Control frames transmitted on\n                       this interface with an opcode indicating the\n                       PAUSE operation.\n\n                       This counter does not increment when the\n                       interface is operating in half-duplex mode.\n\n                       This counter is a 64 bit version of\n                       dot3OutPauseFrames.  It should be used on\n                       interfaces operating at 10 Gb/s or faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3HCStatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 7, 11), )
if mibBuilder.loadTexts: dot3HCStatsTable.setDescription('A table containing 64-bit versions of error\n                       counters from the dot3StatsTable.  The 32-bit\n                       versions of these counters may roll over quite\n                       quickly on higher speed ethernet interfaces.\n                       The counters that have 64-bit versions in this\n                       table are the counters that apply to full-duplex\n                       interfaces, since 10 Gb/s and faster\n                       ethernet-like interfaces do not support\n                       half-duplex, and very few 1000 Mb/s\n                       ethernet-like interfaces support half-duplex.\n\n                       Entries in this table are recommended for\n                       interfaces capable of operating at 1000 Mb/s or\n                       faster, and are required for interfaces capable\n                       of operating at 10 Gb/s or faster.  Lower speed\n                       ethernet-like interfaces do not need entries in\n                       this table, in which case there may be fewer\n                       entries in this table than in the\n                       dot3StatsTable. However, implementations\n                       containing interfaces with a mix of speeds may\n                       choose to implement entries in this table for\n                       all ethernet-like interfaces.')
dot3HCStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 7, 11, 1), ).setIndexNames((0, "EtherLike-MIB", "dot3StatsIndex"))
if mibBuilder.loadTexts: dot3HCStatsEntry.setDescription('An entry containing 64-bit statistics for a\n                       single ethernet-like interface.')
dot3HCStatsAlignmentErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 11, 1, 1), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCStatsAlignmentErrors.setDescription('A count of frames received on a particular\n                       interface that are not an integral number of\n                       octets in length and do not pass the FCS check.\n\n                       The count represented by an instance of this\n                       object is incremented when the alignmentError\n                       status is returned by the MAC service to the\n                       LLC (or other MAC user). Received frames for\n                       which multiple error conditions pertain are,\n                       according to the conventions of IEEE 802.3\n                       Layer Management, counted exclusively according\n                       to the error status presented to the LLC.\n\n                       This counter does not increment for group\n                       encoding schemes greater than 4 bits per group.\n\n                       This counter is a 64 bit version of\n                       dot3StatsAlignmentErrors.  It should be used\n                       on interfaces operating at 10 Gb/s or faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3HCStatsFCSErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 11, 1, 2), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCStatsFCSErrors.setDescription('A count of frames received on a particular\n                       interface that are an integral number of octets\n                       in length but do not pass the FCS check.  This\n                       count does not include frames received with\n                       frame-too-long or frame-too-short error.\n\n                       The count represented by an instance of this\n                       object is incremented when the frameCheckError\n                       status is returned by the MAC service to the\n                       LLC (or other MAC user). Received frames for\n                       which multiple error conditions pertain are,\n                       according to the conventions of IEEE 802.3\n                       Layer Management, counted exclusively according\n                       to the error status presented to the LLC.\n\n                       Note:  Coding errors detected by the physical\n                       layer for speeds above 10 Mb/s will cause the\n                       frame to fail the FCS check.\n\n                       This counter is a 64 bit version of\n                       dot3StatsFCSErrors.  It should be used on\n                       interfaces operating at 10 Gb/s or faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3HCStatsInternalMacTransmitErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 11, 1, 3), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCStatsInternalMacTransmitErrors.setDescription('A count of frames for which transmission on a\n                       particular interface fails due to an internal\n                       MAC sublayer transmit error. A frame is only\n                       counted by an instance of this object if it is\n                       not counted by the corresponding instance of\n                       either the dot3StatsLateCollisions object, the\n                       dot3StatsExcessiveCollisions object, or the\n                       dot3StatsCarrierSenseErrors object.\n\n                       The precise meaning of the count represented by\n                       an instance of this object is implementation-\n                       specific.  In particular, an instance of this\n                       object may represent a count of transmission\n                       errors on a particular interface that are not\n                       otherwise counted.\n\n                       This counter is a 64 bit version of\n                       dot3StatsInternalMacTransmitErrors.  It should\n                       be used on interfaces operating at 10 Gb/s or\n                       faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3HCStatsFrameTooLongs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 11, 1, 4), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCStatsFrameTooLongs.setDescription('A count of frames received on a particular\n                       interface that exceed the maximum permitted\n                       frame size.\n\n                       The count represented by an instance of this\n                       object is incremented when the frameTooLong\n                       status is returned by the MAC service to the\n                       LLC (or other MAC user). Received frames for\n                       which multiple error conditions pertain are,\n                       according to the conventions of IEEE 802.3\n                       Layer Management, counted exclusively according\n                       to the error status presented to the LLC.\n\n                       This counter is a 64 bit version of\n                       dot3StatsFrameTooLongs.  It should be used on\n                       interfaces operating at 10 Gb/s or faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3HCStatsInternalMacReceiveErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 11, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCStatsInternalMacReceiveErrors.setDescription('A count of frames for which reception on a\n                       particular interface fails due to an internal\n                       MAC sublayer receive error. A frame is only\n                       counted by an instance of this object if it is\n                       not counted by the corresponding instance of\n                       either the dot3StatsFrameTooLongs object, the\n                       dot3StatsAlignmentErrors object, or the\n                       dot3StatsFCSErrors object.\n\n                       The precise meaning of the count represented by\n                       an instance of this object is implementation-\n                       specific.  In particular, an instance of this\n                       object may represent a count of receive errors\n                       on a particular interface that are not\n                       otherwise counted.\n\n                       This counter is a 64 bit version of\n                       dot3StatsInternalMacReceiveErrors.  It should be\n                       used on interfaces operating at 10 Gb/s or\n                       faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.')
dot3HCStatsSymbolErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 7, 11, 1, 6), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot3HCStatsSymbolErrors.setDescription("For an interface operating at 100 Mb/s, the\n                       number of times there was an invalid data symbol\n                       when a valid carrier was present.\n                       For an interface operating in half-duplex mode\n                       at 1000 Mb/s, the number of times the receiving\n                       media is non-idle (a carrier event) for a period\n                       of time equal to or greater than slotTime, and\n                       during which there was at least one occurrence\n                       of an event that causes the PHY to indicate\n                       'Data reception error' or 'carrier extend error'\n                       on the GMII.\n\n                       For an interface operating in full-duplex mode\n                       at 1000 Mb/s, the number of times the receiving\n                       media is non-idle (a carrier event) for a period\n                       of time equal to or greater than minFrameSize,\n                       and during which there was at least one\n                       occurrence of an event that causes the PHY to\n                       indicate 'Data reception error' on the GMII.\n\n                       For an interface operating at 10 Gb/s, the\n                       number of times the receiving media is non-idle\n                       (a carrier event) for a period of time equal to\n                       or greater than minFrameSize, and during which\n                       there was at least one occurrence of an event\n                       that causes the PHY to indicate 'Receive Error'\n                       on the XGMII.\n\n                       The count represented by an instance of this\n                       object is incremented at most once per carrier\n                       event, even if multiple symbol errors occur\n                       during the carrier event.  This count does\n                       not increment if a collision is present.\n\n                       This counter is a 64 bit version of\n                       dot3StatsSymbolErrors.  It should be used on\n                       interfaces operating at 10 Gb/s or faster.\n\n                       Discontinuities in the value of this counter can\n                       occur at re-initialization of the management\n                       system, and at other times as indicated by the\n                       value of ifCounterDiscontinuityTime.")
dot3Tests = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 6))
dot3Errors = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 7))
dot3TestTdr = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 6, 1))
if mibBuilder.loadTexts: dot3TestTdr.setDescription('******** THIS IDENTITY IS DEPRECATED *******\n\n                       The Time-Domain Reflectometry (TDR) test is\n                       specific to ethernet-like interfaces of type\n                       10Base5 and 10Base2.  The TDR value may be\n                       useful in determining the approximate distance\n                       to a cable fault.  It is advisable to repeat\n                       this test to check for a consistent resulting\n                       TDR value, to verify that there is a fault.\n\n                       A TDR test returns as its result the time\n                       interval, measured in 10 MHz ticks or 100 nsec\n                       units, between the start of TDR test\n                       transmission and the subsequent detection of a\n                       collision or deassertion of carrier.  On\n                       successful completion of a TDR test, the result\n                       is stored as the value of an appropriate\n                       instance of an appropriate vendor specific MIB\n                       object, and the OBJECT IDENTIFIER of that\n                       instance is stored in the appropriate instance\n                       of the appropriate test result code object\n                       (thereby indicating where the result has been\n                       stored).\n\n                       This object identity has been deprecated, since\n                       the ifTestTable in the IF-MIB was deprecated,\n                       and there is no longer a standard mechanism for\n                       initiating an interface test.  This left no\n                       standard way of using this object identity.')
dot3TestLoopBack = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 6, 2))
if mibBuilder.loadTexts: dot3TestLoopBack.setDescription('******** THIS IDENTITY IS DEPRECATED *******\n\n                       This test configures the MAC chip and executes\n                       an internal loopback test of memory, data paths,\n                       and the MAC chip logic.  This loopback test can\n                       only be executed if the interface is offline.\n                       Once the test has completed, the MAC chip should\n                       be reinitialized for network operation, but it\n                       should remain offline.\n\n                       If an error occurs during a test, the\n                       appropriate test result object will be set\n                       to indicate a failure.  The two OBJECT\n                       IDENTIFIER values dot3ErrorInitError and\n                       dot3ErrorLoopbackError may be used to provided\n                       more information as values for an appropriate\n                       test result code object.\n\n                       This object identity has been deprecated, since\n                       the ifTestTable in the IF-MIB was deprecated,\n                       and there is no longer a standard mechanism for\n                       initiating an interface test.  This left no\n                       standard way of using this object identity.')
dot3ErrorInitError = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 7, 1))
if mibBuilder.loadTexts: dot3ErrorInitError.setDescription("******** THIS IDENTITY IS DEPRECATED *******\n\n                       Couldn't initialize MAC chip for test.\n\n                       This object identity has been deprecated, since\n                       the ifTestTable in the IF-MIB was deprecated,\n                       and there is no longer a standard mechanism for\n                       initiating an interface test.  This left no\n                       standard way of using this object identity.")
dot3ErrorLoopbackError = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 7, 2))
if mibBuilder.loadTexts: dot3ErrorLoopbackError.setDescription('******** THIS IDENTITY IS DEPRECATED *******\n\n                       Expected data not received (or not received\n                       correctly) in loopback test.\n\n                       This object identity has been deprecated, since\n                       the ifTestTable in the IF-MIB was deprecated,\n                       and there is no longer a standard mechanism for\n                       initiating an interface test.  This left no\n                       standard way of using this object identity.')
etherConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 35, 2))
etherGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 35, 2, 1))
etherCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 35, 2, 2))
etherCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 35, 2, 2, 1)).setObjects(*(("EtherLike-MIB", "etherStatsGroup"), ("EtherLike-MIB", "etherCollisionTableGroup"),))
if mibBuilder.loadTexts: etherCompliance.setDescription('******** THIS COMPLIANCE IS DEPRECATED ********\n\n                       The compliance statement for managed network\n                       entities which have ethernet-like network\n                       interfaces.\n\n                       This compliance is deprecated and replaced by\n                       dot3Compliance.')
ether100MbsCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 35, 2, 2, 2)).setObjects(*(("EtherLike-MIB", "etherStats100MbsGroup"), ("EtherLike-MIB", "etherCollisionTableGroup"),))
if mibBuilder.loadTexts: ether100MbsCompliance.setDescription('******** THIS COMPLIANCE IS DEPRECATED ********\n\n                       The compliance statement for managed network\n                       entities which have 100 Mb/sec ethernet-like\n                       network interfaces.\n\n                       This compliance is deprecated and replaced by\n                       dot3Compliance.')
dot3Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 35, 2, 2, 3)).setObjects(*(("EtherLike-MIB", "etherStatsBaseGroup"), ("EtherLike-MIB", "etherDuplexGroup"), ("EtherLike-MIB", "etherStatsLowSpeedGroup"), ("EtherLike-MIB", "etherStatsHighSpeedGroup"), ("EtherLike-MIB", "etherControlGroup"), ("EtherLike-MIB", "etherControlPauseGroup"), ("EtherLike-MIB", "etherCollisionTableGroup"),))
if mibBuilder.loadTexts: dot3Compliance.setDescription('******** THIS COMPLIANCE IS DEPRECATED ********\n\n                       The compliance statement for managed network\n                       entities which have ethernet-like network\n                       interfaces.\n\n                       This compliance is deprecated and replaced by\n                       dot3Compliance2.')
dot3Compliance2 = ModuleCompliance((1, 3, 6, 1, 2, 1, 35, 2, 2, 4)).setObjects(*(("EtherLike-MIB", "etherStatsBaseGroup2"), ("EtherLike-MIB", "etherDuplexGroup"), ("EtherLike-MIB", "etherRateControlGroup"), ("EtherLike-MIB", "etherStatsLowSpeedGroup"), ("EtherLike-MIB", "etherStatsHighSpeedGroup"), ("EtherLike-MIB", "etherStatsHalfDuplexGroup"), ("EtherLike-MIB", "etherHCStatsGroup"), ("EtherLike-MIB", "etherControlGroup"), ("EtherLike-MIB", "etherHCControlGroup"), ("EtherLike-MIB", "etherControlPauseGroup"), ("EtherLike-MIB", "etherHCControlPauseGroup"), ("EtherLike-MIB", "etherCollisionTableGroup"),))
if mibBuilder.loadTexts: dot3Compliance2.setDescription('The compliance statement for managed network\n                           entities which have ethernet-like network\n                           interfaces.\n\n                           Note that compliance with this MIB module\n                           requires compliance with the ifCompliance3\n                           MODULE-COMPLIANCE statement of the IF-MIB\n                           (RFC2863).  In addition, compliance with this\n                           MIB module requires compliance  with the\n                           mauModIfCompl3 MODULE-COMPLIANCE statement of\n                           the MAU-MIB (RFC3636).')
etherStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 1)).setObjects(*(("EtherLike-MIB", "dot3StatsIndex"), ("EtherLike-MIB", "dot3StatsAlignmentErrors"), ("EtherLike-MIB", "dot3StatsFCSErrors"), ("EtherLike-MIB", "dot3StatsSingleCollisionFrames"), ("EtherLike-MIB", "dot3StatsMultipleCollisionFrames"), ("EtherLike-MIB", "dot3StatsSQETestErrors"), ("EtherLike-MIB", "dot3StatsDeferredTransmissions"), ("EtherLike-MIB", "dot3StatsLateCollisions"), ("EtherLike-MIB", "dot3StatsExcessiveCollisions"), ("EtherLike-MIB", "dot3StatsInternalMacTransmitErrors"), ("EtherLike-MIB", "dot3StatsCarrierSenseErrors"), ("EtherLike-MIB", "dot3StatsFrameTooLongs"), ("EtherLike-MIB", "dot3StatsInternalMacReceiveErrors"), ("EtherLike-MIB", "dot3StatsEtherChipSet"),))
if mibBuilder.loadTexts: etherStatsGroup.setDescription('********* THIS GROUP IS DEPRECATED **********\n\n                       A collection of objects providing information\n                       applicable to all ethernet-like network\n                       interfaces.\n\n                       This object group has been deprecated and\n                       replaced by etherStatsBaseGroup and\n                       etherStatsLowSpeedGroup.')
etherCollisionTableGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 2)).setObjects(*(("EtherLike-MIB", "dot3CollFrequencies"),))
if mibBuilder.loadTexts: etherCollisionTableGroup.setDescription('A collection of objects providing a histogram\n                       of packets successfully transmitted after\n                       experiencing exactly N collisions.')
etherStats100MbsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 3)).setObjects(*(("EtherLike-MIB", "dot3StatsIndex"), ("EtherLike-MIB", "dot3StatsAlignmentErrors"), ("EtherLike-MIB", "dot3StatsFCSErrors"), ("EtherLike-MIB", "dot3StatsSingleCollisionFrames"), ("EtherLike-MIB", "dot3StatsMultipleCollisionFrames"), ("EtherLike-MIB", "dot3StatsDeferredTransmissions"), ("EtherLike-MIB", "dot3StatsLateCollisions"), ("EtherLike-MIB", "dot3StatsExcessiveCollisions"), ("EtherLike-MIB", "dot3StatsInternalMacTransmitErrors"), ("EtherLike-MIB", "dot3StatsCarrierSenseErrors"), ("EtherLike-MIB", "dot3StatsFrameTooLongs"), ("EtherLike-MIB", "dot3StatsInternalMacReceiveErrors"), ("EtherLike-MIB", "dot3StatsEtherChipSet"), ("EtherLike-MIB", "dot3StatsSymbolErrors"),))
if mibBuilder.loadTexts: etherStats100MbsGroup.setDescription('********* THIS GROUP IS DEPRECATED **********\n\n                       A collection of objects providing information\n                       applicable to 100 Mb/sec ethernet-like network\n                       interfaces.\n\n                       This object group has been deprecated and\n                       replaced by etherStatsBaseGroup and\n                       etherStatsHighSpeedGroup.')
etherStatsBaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 4)).setObjects(*(("EtherLike-MIB", "dot3StatsIndex"), ("EtherLike-MIB", "dot3StatsAlignmentErrors"), ("EtherLike-MIB", "dot3StatsFCSErrors"), ("EtherLike-MIB", "dot3StatsSingleCollisionFrames"), ("EtherLike-MIB", "dot3StatsMultipleCollisionFrames"), ("EtherLike-MIB", "dot3StatsDeferredTransmissions"), ("EtherLike-MIB", "dot3StatsLateCollisions"), ("EtherLike-MIB", "dot3StatsExcessiveCollisions"), ("EtherLike-MIB", "dot3StatsInternalMacTransmitErrors"), ("EtherLike-MIB", "dot3StatsCarrierSenseErrors"), ("EtherLike-MIB", "dot3StatsFrameTooLongs"), ("EtherLike-MIB", "dot3StatsInternalMacReceiveErrors"),))
if mibBuilder.loadTexts: etherStatsBaseGroup.setDescription('********* THIS GROUP IS DEPRECATED **********\n\n                       A collection of objects providing information\n                       applicable to all ethernet-like network\n                       interfaces.\n\n                       This object group has been deprecated and\n                       replaced by etherStatsBaseGroup2 and\n                       etherStatsHalfDuplexGroup, to separate\n                       objects which must be implemented by all\n                       ethernet-like network interfaces from\n                       objects that need only be implemented on\n                       ethernet-like network interfaces that are\n                       capable of half-duplex operation.')
etherStatsLowSpeedGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 5)).setObjects(*(("EtherLike-MIB", "dot3StatsSQETestErrors"),))
if mibBuilder.loadTexts: etherStatsLowSpeedGroup.setDescription('A collection of objects providing information\n                       applicable to ethernet-like network interfaces\n                       capable of operating at 10 Mb/s or slower in\n                       half-duplex mode.')
etherStatsHighSpeedGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 6)).setObjects(*(("EtherLike-MIB", "dot3StatsSymbolErrors"),))
if mibBuilder.loadTexts: etherStatsHighSpeedGroup.setDescription('A collection of objects providing information\n                       applicable to ethernet-like network interfaces\n                       capable of operating at 100 Mb/s or faster.')
etherDuplexGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 7)).setObjects(*(("EtherLike-MIB", "dot3StatsDuplexStatus"),))
if mibBuilder.loadTexts: etherDuplexGroup.setDescription('A collection of objects providing information\n                       about the duplex mode of an ethernet-like\n                       network interface.')
etherControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 8)).setObjects(*(("EtherLike-MIB", "dot3ControlFunctionsSupported"), ("EtherLike-MIB", "dot3ControlInUnknownOpcodes"),))
if mibBuilder.loadTexts: etherControlGroup.setDescription('A collection of objects providing information\n                       about the MAC Control sublayer on ethernet-like\n                       network interfaces.')
etherControlPauseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 9)).setObjects(*(("EtherLike-MIB", "dot3PauseAdminMode"), ("EtherLike-MIB", "dot3PauseOperMode"), ("EtherLike-MIB", "dot3InPauseFrames"), ("EtherLike-MIB", "dot3OutPauseFrames"),))
if mibBuilder.loadTexts: etherControlPauseGroup.setDescription('A collection of objects providing information\n                       about and control of the MAC Control PAUSE\n                       function on ethernet-like network interfaces.')
etherStatsBaseGroup2 = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 10)).setObjects(*(("EtherLike-MIB", "dot3StatsIndex"), ("EtherLike-MIB", "dot3StatsAlignmentErrors"), ("EtherLike-MIB", "dot3StatsFCSErrors"), ("EtherLike-MIB", "dot3StatsInternalMacTransmitErrors"), ("EtherLike-MIB", "dot3StatsFrameTooLongs"), ("EtherLike-MIB", "dot3StatsInternalMacReceiveErrors"),))
if mibBuilder.loadTexts: etherStatsBaseGroup2.setDescription('A collection of objects providing information\n                       applicable to all ethernet-like network\n                       interfaces.')
etherStatsHalfDuplexGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 11)).setObjects(*(("EtherLike-MIB", "dot3StatsSingleCollisionFrames"), ("EtherLike-MIB", "dot3StatsMultipleCollisionFrames"), ("EtherLike-MIB", "dot3StatsDeferredTransmissions"), ("EtherLike-MIB", "dot3StatsLateCollisions"), ("EtherLike-MIB", "dot3StatsExcessiveCollisions"), ("EtherLike-MIB", "dot3StatsCarrierSenseErrors"),))
if mibBuilder.loadTexts: etherStatsHalfDuplexGroup.setDescription('A collection of objects providing information\n                       applicable only to half-duplex ethernet-like\n                       network interfaces.')
etherHCStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 12)).setObjects(*(("EtherLike-MIB", "dot3HCStatsAlignmentErrors"), ("EtherLike-MIB", "dot3HCStatsFCSErrors"), ("EtherLike-MIB", "dot3HCStatsInternalMacTransmitErrors"), ("EtherLike-MIB", "dot3HCStatsFrameTooLongs"), ("EtherLike-MIB", "dot3HCStatsInternalMacReceiveErrors"), ("EtherLike-MIB", "dot3HCStatsSymbolErrors"),))
if mibBuilder.loadTexts: etherHCStatsGroup.setDescription('A collection of objects providing high-capacity\n                       statistics applicable to higher-speed\n                       ethernet-like network interfaces.')
etherHCControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 13)).setObjects(*(("EtherLike-MIB", "dot3HCControlInUnknownOpcodes"),))
if mibBuilder.loadTexts: etherHCControlGroup.setDescription('A collection of objects providing high-capacity\n                       statistics for the MAC Control sublayer on\n                       higher-speed ethernet-like network interfaces.')
etherHCControlPauseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 14)).setObjects(*(("EtherLike-MIB", "dot3HCInPauseFrames"), ("EtherLike-MIB", "dot3HCOutPauseFrames"),))
if mibBuilder.loadTexts: etherHCControlPauseGroup.setDescription('A collection of objects providing high-capacity\n                       statistics for the MAC Control PAUSE function on\n                       higher-speed ethernet-like network interfaces.')
etherRateControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 35, 2, 1, 15)).setObjects(*(("EtherLike-MIB", "dot3StatsRateControlAbility"), ("EtherLike-MIB", "dot3StatsRateControlStatus"),))
if mibBuilder.loadTexts: etherRateControlGroup.setDescription('A collection of objects providing information\n                       about the Rate Control function on ethernet-like\n                       interfaces.')
mibBuilder.exportSymbols("EtherLike-MIB", dot3CollEntry=dot3CollEntry, dot3StatsAlignmentErrors=dot3StatsAlignmentErrors, dot3StatsCarrierSenseErrors=dot3StatsCarrierSenseErrors, dot3HCControlInUnknownOpcodes=dot3HCControlInUnknownOpcodes, dot3PauseEntry=dot3PauseEntry, dot3ErrorLoopbackError=dot3ErrorLoopbackError, etherStats100MbsGroup=etherStats100MbsGroup, etherStatsHighSpeedGroup=etherStatsHighSpeedGroup, dot3InPauseFrames=dot3InPauseFrames, dot3StatsExcessiveCollisions=dot3StatsExcessiveCollisions, dot3Compliance=dot3Compliance, etherStatsGroup=etherStatsGroup, dot3StatsDeferredTransmissions=dot3StatsDeferredTransmissions, etherRateControlGroup=etherRateControlGroup, dot3PauseTable=dot3PauseTable, dot3HCOutPauseFrames=dot3HCOutPauseFrames, dot3PauseAdminMode=dot3PauseAdminMode, etherMIBObjects=etherMIBObjects, etherDuplexGroup=etherDuplexGroup, etherCompliance=etherCompliance, etherConformance=etherConformance, dot3TestLoopBack=dot3TestLoopBack, dot3StatsMultipleCollisionFrames=dot3StatsMultipleCollisionFrames, etherControlGroup=etherControlGroup, etherControlPauseGroup=etherControlPauseGroup, dot3Errors=dot3Errors, etherCompliances=etherCompliances, etherCollisionTableGroup=etherCollisionTableGroup, etherStatsLowSpeedGroup=etherStatsLowSpeedGroup, dot3HCStatsEntry=dot3HCStatsEntry, dot3HCStatsInternalMacTransmitErrors=dot3HCStatsInternalMacTransmitErrors, dot3HCStatsFrameTooLongs=dot3HCStatsFrameTooLongs, ether100MbsCompliance=ether100MbsCompliance, dot3CollTable=dot3CollTable, dot3StatsIndex=dot3StatsIndex, dot3StatsEntry=dot3StatsEntry, dot3HCStatsAlignmentErrors=dot3HCStatsAlignmentErrors, dot3ControlTable=dot3ControlTable, etherStatsBaseGroup2=etherStatsBaseGroup2, etherHCControlPauseGroup=etherHCControlPauseGroup, dot3HCStatsTable=dot3HCStatsTable, dot3StatsEtherChipSet=dot3StatsEtherChipSet, dot3ControlEntry=dot3ControlEntry, dot3ErrorInitError=dot3ErrorInitError, dot3StatsFCSErrors=dot3StatsFCSErrors, dot3StatsRateControlAbility=dot3StatsRateControlAbility, dot3ControlFunctionsSupported=dot3ControlFunctionsSupported, dot3CollFrequencies=dot3CollFrequencies, dot3StatsTable=dot3StatsTable, dot3HCStatsInternalMacReceiveErrors=dot3HCStatsInternalMacReceiveErrors, dot3TestTdr=dot3TestTdr, dot3StatsSingleCollisionFrames=dot3StatsSingleCollisionFrames, dot3StatsLateCollisions=dot3StatsLateCollisions, etherStatsBaseGroup=etherStatsBaseGroup, dot3Tests=dot3Tests, etherStatsHalfDuplexGroup=etherStatsHalfDuplexGroup, dot3ControlInUnknownOpcodes=dot3ControlInUnknownOpcodes, dot3StatsInternalMacReceiveErrors=dot3StatsInternalMacReceiveErrors, dot3StatsDuplexStatus=dot3StatsDuplexStatus, PYSNMP_MODULE_ID=etherMIB, dot3HCStatsSymbolErrors=dot3HCStatsSymbolErrors, dot3HCStatsFCSErrors=dot3HCStatsFCSErrors, dot3StatsInternalMacTransmitErrors=dot3StatsInternalMacTransmitErrors, dot3CollCount=dot3CollCount, dot3Compliance2=dot3Compliance2, dot3StatsSQETestErrors=dot3StatsSQETestErrors, etherHCControlGroup=etherHCControlGroup, etherHCStatsGroup=etherHCStatsGroup, dot3=dot3, dot3StatsRateControlStatus=dot3StatsRateControlStatus, dot3PauseOperMode=dot3PauseOperMode, dot3StatsSymbolErrors=dot3StatsSymbolErrors, etherMIB=etherMIB, etherGroups=etherGroups, dot3HCInPauseFrames=dot3HCInPauseFrames, dot3StatsFrameTooLongs=dot3StatsFrameTooLongs, dot3OutPauseFrames=dot3OutPauseFrames)



#
# PySNMP MIB module IANA-GMPLS-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANA-GMPLS-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:14:16 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, MibIdentifier, mib_2, TimeTicks, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, Integer32, ObjectIdentity, iso, Unsigned32, Counter64, NotificationType, Bits, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "MibIdentifier", "mib-2", "TimeTicks", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "Integer32", "ObjectIdentity", "iso", "Unsigned32", "Counter64", "NotificationType", "Bits", "IpAddress")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
ianaGmpls = ModuleIdentity((1, 3, 6, 1, 2, 1, 152)).setRevisions(("2007-02-27 00:00",))
if mibBuilder.loadTexts: ianaGmpls.setLastUpdated('200702270000Z')
if mibBuilder.loadTexts: ianaGmpls.setOrganization('IANA')
if mibBuilder.loadTexts: ianaGmpls.setContactInfo('Internet Assigned Numbers Authority\n                   Postal: 4676 Admiralty Way, Suite 330\n                           Marina del Rey, CA 90292\n                   Tel:    +1 310 823 9358\n                   E-Mail: iana@iana.org')
if mibBuilder.loadTexts: ianaGmpls.setDescription('Copyright (C) The IETF Trust (2007).  The initial version\n          of this MIB module was published in RFC 4802.  For full legal\n          notices see the RFC itself.  Supplementary information\n          may be available on:\n          http://www.ietf.org/copyrights/ianamib.html')
class IANAGmplsLSPEncodingTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 5, 7, 8, 9, 11, 12, 13,))
    namedValues = NamedValues(("tunnelLspNotGmpls", 0), ("tunnelLspPacket", 1), ("tunnelLspEthernet", 2), ("tunnelLspAnsiEtsiPdh", 3), ("tunnelLspSdhSonet", 5), ("tunnelLspDigitalWrapper", 7), ("tunnelLspLambda", 8), ("tunnelLspFiber", 9), ("tunnelLspFiberChannel", 11), ("tunnelDigitalPath", 12), ("tunnelOpticalChannel", 13),)

class IANAGmplsSwitchingTypeTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 51, 100, 150, 200,))
    namedValues = NamedValues(("unknown", 0), ("psc1", 1), ("psc2", 2), ("psc3", 3), ("psc4", 4), ("l2sc", 51), ("tdm", 100), ("lsc", 150), ("fsc", 200),)

class IANAGmplsGeneralizedPidTC(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 36, 37, 38, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58,))
    namedValues = NamedValues(("unknown", 0), ("asynchE4", 5), ("asynchDS3T3", 6), ("asynchE3", 7), ("bitsynchE3", 8), ("bytesynchE3", 9), ("asynchDS2T2", 10), ("bitsynchDS2T2", 11), ("reservedByRFC3471first", 12), ("asynchE1", 13), ("bytesynchE1", 14), ("bytesynch31ByDS0", 15), ("asynchDS1T1", 16), ("bitsynchDS1T1", 17), ("bytesynchDS1T1", 18), ("vc1vc12", 19), ("reservedByRFC3471second", 20), ("reservedByRFC3471third", 21), ("ds1SFAsynch", 22), ("ds1ESFAsynch", 23), ("ds3M23Asynch", 24), ("ds3CBitParityAsynch", 25), ("vtLovc", 26), ("stsSpeHovc", 27), ("posNoScramble16BitCrc", 28), ("posNoScramble32BitCrc", 29), ("posScramble16BitCrc", 30), ("posScramble32BitCrc", 31), ("atm", 32), ("ethernet", 33), ("sdhSonet", 34), ("digitalwrapper", 36), ("lambda", 37), ("ansiEtsiPdh", 38), ("lapsSdh", 40), ("fddi", 41), ("dqdb", 42), ("fiberChannel3", 43), ("hdlc", 44), ("ethernetV2DixOnly", 45), ("ethernet802dot3Only", 46), ("g709ODUj", 47), ("g709OTUk", 48), ("g709CBRorCBRa", 49), ("g709CBRb", 50), ("g709BSOT", 51), ("g709BSNT", 52), ("gfpIPorPPP", 53), ("gfpEthernetMAC", 54), ("gfpEthernetPHY", 55), ("g709ESCON", 56), ("g709FICON", 57), ("g709FiberChannel", 58),)

class IANAGmplsAdminStatusInformationTC(Bits, TextualConvention):
    namedValues = NamedValues(("reflect", 0), ("reserved1", 1), ("reserved2", 2), ("reserved3", 3), ("reserved4", 4), ("reserved5", 5), ("reserved6", 6), ("reserved7", 7), ("reserved8", 8), ("reserved9", 9), ("reserved10", 10), ("reserved11", 11), ("reserved12", 12), ("reserved13", 13), ("reserved14", 14), ("reserved15", 15), ("reserved16", 16), ("reserved17", 17), ("reserved18", 18), ("reserved19", 19), ("reserved20", 20), ("reserved21", 21), ("reserved22", 22), ("reserved23", 23), ("reserved24", 24), ("reserved25", 25), ("reserved26", 26), ("reserved27", 27), ("reserved28", 28), ("testing", 29), ("administrativelyDown", 30), ("deleteInProgress", 31),)

mibBuilder.exportSymbols("IANA-GMPLS-TC-MIB", IANAGmplsLSPEncodingTypeTC=IANAGmplsLSPEncodingTypeTC, PYSNMP_MODULE_ID=ianaGmpls, ianaGmpls=ianaGmpls, IANAGmplsAdminStatusInformationTC=IANAGmplsAdminStatusInformationTC, IANAGmplsSwitchingTypeTC=IANAGmplsSwitchingTypeTC, IANAGmplsGeneralizedPidTC=IANAGmplsGeneralizedPidTC)



#
# PySNMP MIB module VDSL-LINE-EXT-MCM-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/VDSL-LINE-EXT-MCM-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:32:42 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Integer32, ObjectIdentity, iso, Unsigned32, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, IpAddress, Bits, NotificationType, Counter64, transmission, Gauge32, ModuleIdentity, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "ObjectIdentity", "iso", "Unsigned32", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "IpAddress", "Bits", "NotificationType", "Counter64", "transmission", "Gauge32", "ModuleIdentity", "Counter32")
( RowStatus, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "DisplayString")
( vdslLineConfProfileName, ) = mibBuilder.importSymbols("VDSL-LINE-MIB", "vdslLineConfProfileName")
vdslExtMCMMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 229)).setRevisions(("2005-04-28 00:00",))
if mibBuilder.loadTexts: vdslExtMCMMIB.setLastUpdated('200504280000Z')
if mibBuilder.loadTexts: vdslExtMCMMIB.setOrganization('ADSLMIB Working Group')
if mibBuilder.loadTexts: vdslExtMCMMIB.setContactInfo('WG-email:  adslmib@ietf.org\n         Info:      https://www1.ietf.org/mailman/listinfo/adslmib\n\n         Chair:     Mike Sneed\n                    Sand Channel Systems\n         Postal:    P.O. Box 37324\n                    Raleigh NC 27627-732\n         Email:     sneedmike@hotmail.com\n         Phone:     +1 206 600 7022\n\n         Co-Chair/Co-editor:\n                    Bob Ray\n                    PESA Switching Systems, Inc.\n         Postal:    330-A Wynn Drive\n                    Huntsville, AL 35805\n                    USA\n         Email:     rray@pesa.com\n         Phone:     +1 256 726 9200 ext.  142\n\n\n\n\n         Co-editor: Menachem Dodge\n                    ECI Telecom Ltd.\n         Postal:    30 hasivim St.\n                    Petach Tikva 49517,\n                    Israel.\n         Email:     mbdodge@ieee.org\n         Phone:     +972 3 926 8421\n        ')
if mibBuilder.loadTexts: vdslExtMCMMIB.setDescription('The VDSL-LINE-MIB found in RFC 3728 defines objects for\n    the management of a pair of VDSL transceivers at each end of\n    the VDSL line.  The VDSL-LINE-MIB configures and monitors the\n    line code independent parameters (TC layer) of the VDSL line.\n    This MIB module is an optional extension of the VDSL-LINE-MIB\n    and defines objects for configuration and monitoring of the\n    line code specific (LCS) elements (PMD layer) for VDSL lines\n    using MCM coding.  The objects in this extension MIB MUST NOT\n    be used for VDSL lines using Single Carrier Modulation (SCM)\n    line coding.  If an object in this extension MIB is referenced\n    by a line which does not use MCM, it has no effect on the\n    operation of that line.\n\n    Naming Conventions:\n        Vtuc -- (VTUC) transceiver at near (Central) end of line\n        Vtur -- (VTUR) transceiver at Remote end of line\n        Vtu  -- One of either Vtuc or Vtur\n        Curr -- Current\n        LCS  -- Line Code Specific\n        Max  -- Maximum\n        PSD  -- Power Spectral Density\n        Rx   -- Receive\n        Tx   -- Transmit\n\n    Copyright (C) The Internet Society (2005).  This version\n    of this MIB module is part of RFC 4070: see the RFC\n    itself for full legal notices.')
vdslLineExtMCMMib = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1))
vdslLineExtMCMMibObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 1))
vdslLineMCMConfProfileTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileTable.setDescription('This table contains additional information on multiple\n        carrier VDSL lines.  One entry in this table reflects a\n        profile defined by a manager which can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileEntry.setDescription('Each entry consists of a list of parameters that\n        represents the configuration of a multiple carrier\n        modulation VDSL modem.')
vdslLineMCMConfProfileTxWindowLength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,255))).setUnits('samples').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxWindowLength.setDescription('Specifies the length of the transmit window, counted\n        in samples at the sampling rate corresponding to the\n        negotiated value of N.')
vdslLineMCMConfProfileRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 1, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must first be unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileTxBandTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandTable.setDescription('This table contains transmit band descriptor configuration\n        information for a VDSL line.  Each entry in this table\n        reflects the configuration for one of possibly many bands\n        with a multiple carrier modulation (MCM) VDSL line.\n        These entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileTxBandEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandEntry.setDescription('Each entry consists of a transmit band descriptor, which\n        is defined by a start and a stop tone index.')
vdslLineMCMConfProfileTxBandNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileTxBandStart = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandStart.setDescription('Start tone index for this band.')
vdslLineMCMConfProfileTxBandStop = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandStop.setDescription('Stop tone index for this band.')
vdslLineMCMConfProfileTxBandRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 2, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxBandRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n\n\n\n\n        Each entry must be internally consistent, the Stop Tone must\n        be greater than the Start Tone.  Each entry must also be\n        externally consistent, all entries indexed by a specific\n        profile must not overlap.  Validation of the profile will\n        check both internal and external consistency.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileRxBandTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandTable.setDescription('This table contains receive band descriptor configuration\n        information for a VDSL line.  Each entry in this table\n        reflects the configuration for one of possibly many bands\n        with a multiple carrier modulation (MCM) VDSL line.\n        These entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileRxBandEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandEntry.setDescription('Each entry consists of a transmit band descriptor, which\n        is defined by a start and a stop tone index.')
vdslLineMCMConfProfileRxBandNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileRxBandStart = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandStart.setDescription('Start tone index for this band.')
vdslLineMCMConfProfileRxBandStop = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandStop.setDescription('Stop tone index for this band.')
vdslLineMCMConfProfileRxBandRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 3, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileRxBandRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n        Each entry must be internally consistent, the Stop Tone must\n        be greater than the Start Tone.  Each entry must also be\n        externally consistent, all entries indexed by a specific\n\n\n\n        profile must not overlap.  Validation of the profile will\n        check both internal and external consistency.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileTxPSDTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDTable.setDescription('This table contains transmit PSD mask descriptor\n        configuration information for a VDSL line.  Each entry in\n        this table reflects the configuration for one tone within\n        a multiple carrier modulation (MCM) VDSL line.  These\n        entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileTxPSDEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDEntry.setDescription('Each entry consists of a transmit PSD mask descriptor,\n        which defines the power spectral density (PSD) for a tone.')
vdslLineMCMConfProfileTxPSDNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDNumber.setDescription('The index for this mask descriptor entry.')
vdslLineMCMConfProfileTxPSDTone = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDTone.setDescription('The tone index for which the PSD is being specified.')
vdslLineMCMConfProfileTxPSDPSD = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 3), Unsigned32()).setUnits('0.5dBm/Hz').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDPSD.setDescription('Power Spectral Density level in steps of 0.5dBm/Hz with\n        an offset of -140dBm/Hz.')
vdslLineMCMConfProfileTxPSDRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 4, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileTxPSDRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n\n\n\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileMaxTxPSDTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDTable.setDescription('This table contains transmit maximum PSD mask descriptor\n        configuration information for a VDSL line.  Each entry in\n        this table reflects the configuration for one tone within\n        a multiple carrier modulation (MCM) VDSL modem.  These\n        entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileMaxTxPSDEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDEntry.setDescription('Each entry consists of a transmit PSD mask descriptor,\n        which defines the maximum power spectral density (PSD)\n        for a tone.')
vdslLineMCMConfProfileMaxTxPSDNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileMaxTxPSDTone = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDTone.setDescription('The tone index for which the PSD is being specified.\n         There must not be multiple rows defined, for a particular\n         profile, with the same value for this field.')
vdslLineMCMConfProfileMaxTxPSDPSD = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 3), Unsigned32()).setUnits('0.5dBm/Hz').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDPSD.setDescription('Power Spectral Density level in steps of 0.5dBm/Hz with\n        an offset of -140dBm/Hz.')
vdslLineMCMConfProfileMaxTxPSDRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 5, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxTxPSDRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n        There must be only one entry in this table for each tone\n        associated with a specific profile.  This will be checked\n        during the validation process.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineMCMConfProfileMaxRxPSDTable = MibTable((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6), )
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDTable.setDescription('This table contains maximum receive PSD mask descriptor\n        configuration information for a VDSL line.  Each entry in\n        this table reflects the configuration for one tone within\n        a multiple carrier modulation (MCM) VDSL modem.  These\n        entries are defined by a manager and can be used to\n        configure the VDSL line.\n\n        If an entry in this table is referenced by a line which\n        does not use MCM, it has no effect on the operation of that\n        line.\n\n        All read-create-objects defined in this table SHOULD be\n        stored persistently.')
vdslLineMCMConfProfileMaxRxPSDEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1), ).setIndexNames((0, "VDSL-LINE-MIB", "vdslLineConfProfileName"), (0, "VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDNumber"))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDEntry.setDescription('Each entry consists of a transmit PSD mask descriptor,\n        which defines the power spectral density (PSD) for a\n        tone.')
vdslLineMCMConfProfileMaxRxPSDNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096)))
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDNumber.setDescription('The index for this band descriptor entry.')
vdslLineMCMConfProfileMaxRxPSDTone = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4096))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDTone.setDescription('The tone index for which the PSD is being specified.\n         There must not be multiple rows defined, for a particular\n         profile, with the same value for this field.')
vdslLineMCMConfProfileMaxRxPSDPSD = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 3), Unsigned32()).setUnits('0.5dBm/Hz').setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDPSD.setDescription('Power Spectral Density level in steps of 0.5dBm/Hz with\n        an offset of -140dBm/Hz.')
vdslLineMCMConfProfileMaxRxPSDRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 229, 1, 1, 6, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: vdslLineMCMConfProfileMaxRxPSDRowStatus.setDescription("This object is used to create a new row or modify or\n        delete an existing row in this table.\n\n        A profile is activated by setting this object to `active'.\n        When `active' is set, the system will validate the profile.\n        There must be only one entry in this table for each tone\n        associated with a specific profile.  This will be checked\n        during the validation process.\n\n        None of the columns in this row may be modified while the\n        row is in the 'active' state.\n\n        Before a profile can be deleted or taken out of\n        service, (by setting this object to `destroy' or\n        `notInService') it must be first unreferenced\n        from all associated lines.")
vdslLineExtMCMConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 2))
vdslLineExtMCMGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 1))
vdslLineExtMCMCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 2))
vdslLineExtMCMMibCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 2, 1)).setObjects(*(("VDSL-LINE-EXT-MCM-MIB", "vdslLineExtMCMGroup"),))
if mibBuilder.loadTexts: vdslLineExtMCMMibCompliance.setDescription('The compliance statement for SNMP entities which\n        manage VDSL interfaces.')
vdslLineExtMCMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 229, 1, 2, 1, 1)).setObjects(*(("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxWindowLength"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandStart"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandStop"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxBandRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandStart"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandStop"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileRxBandRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDTone"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDPSD"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileTxPSDRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDTone"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDPSD"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxTxPSDRowStatus"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDTone"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDPSD"), ("VDSL-LINE-EXT-MCM-MIB", "vdslLineMCMConfProfileMaxRxPSDRowStatus"),))
if mibBuilder.loadTexts: vdslLineExtMCMGroup.setDescription('A collection of objects providing configuration\n\n\n\n             information for a VDSL line based upon multiple\n             carrier modulation modem.')
mibBuilder.exportSymbols("VDSL-LINE-EXT-MCM-MIB", vdslLineExtMCMGroup=vdslLineExtMCMGroup, vdslLineMCMConfProfileTxPSDNumber=vdslLineMCMConfProfileTxPSDNumber, vdslLineMCMConfProfileMaxRxPSDTable=vdslLineMCMConfProfileMaxRxPSDTable, vdslLineMCMConfProfileRxBandStart=vdslLineMCMConfProfileRxBandStart, vdslLineMCMConfProfileMaxTxPSDPSD=vdslLineMCMConfProfileMaxTxPSDPSD, vdslLineMCMConfProfileTxBandRowStatus=vdslLineMCMConfProfileTxBandRowStatus, vdslLineExtMCMCompliances=vdslLineExtMCMCompliances, vdslLineMCMConfProfileMaxTxPSDTable=vdslLineMCMConfProfileMaxTxPSDTable, vdslLineMCMConfProfileRxBandTable=vdslLineMCMConfProfileRxBandTable, vdslLineMCMConfProfileTxBandEntry=vdslLineMCMConfProfileTxBandEntry, vdslLineExtMCMMibObjects=vdslLineExtMCMMibObjects, vdslLineMCMConfProfileTxBandStart=vdslLineMCMConfProfileTxBandStart, vdslLineMCMConfProfileMaxRxPSDPSD=vdslLineMCMConfProfileMaxRxPSDPSD, vdslLineMCMConfProfileMaxTxPSDNumber=vdslLineMCMConfProfileMaxTxPSDNumber, vdslLineMCMConfProfileMaxTxPSDTone=vdslLineMCMConfProfileMaxTxPSDTone, vdslLineMCMConfProfileMaxRxPSDRowStatus=vdslLineMCMConfProfileMaxRxPSDRowStatus, vdslLineMCMConfProfileRxBandStop=vdslLineMCMConfProfileRxBandStop, vdslLineMCMConfProfileTxWindowLength=vdslLineMCMConfProfileTxWindowLength, vdslLineMCMConfProfileTxPSDPSD=vdslLineMCMConfProfileTxPSDPSD, vdslLineMCMConfProfileMaxRxPSDEntry=vdslLineMCMConfProfileMaxRxPSDEntry, vdslLineExtMCMMibCompliance=vdslLineExtMCMMibCompliance, vdslLineMCMConfProfileMaxRxPSDNumber=vdslLineMCMConfProfileMaxRxPSDNumber, vdslLineMCMConfProfileTxBandStop=vdslLineMCMConfProfileTxBandStop, vdslLineMCMConfProfileTxPSDTone=vdslLineMCMConfProfileTxPSDTone, vdslLineMCMConfProfileMaxRxPSDTone=vdslLineMCMConfProfileMaxRxPSDTone, vdslLineMCMConfProfileTxBandTable=vdslLineMCMConfProfileTxBandTable, vdslLineMCMConfProfileRxBandNumber=vdslLineMCMConfProfileRxBandNumber, vdslLineMCMConfProfileMaxTxPSDEntry=vdslLineMCMConfProfileMaxTxPSDEntry, vdslLineMCMConfProfileEntry=vdslLineMCMConfProfileEntry, vdslLineMCMConfProfileTxPSDEntry=vdslLineMCMConfProfileTxPSDEntry, vdslLineMCMConfProfileTxBandNumber=vdslLineMCMConfProfileTxBandNumber, PYSNMP_MODULE_ID=vdslExtMCMMIB, vdslLineMCMConfProfileRxBandEntry=vdslLineMCMConfProfileRxBandEntry, vdslLineMCMConfProfileTxPSDRowStatus=vdslLineMCMConfProfileTxPSDRowStatus, vdslLineMCMConfProfileRowStatus=vdslLineMCMConfProfileRowStatus, vdslLineMCMConfProfileRxBandRowStatus=vdslLineMCMConfProfileRxBandRowStatus, vdslLineMCMConfProfileTable=vdslLineMCMConfProfileTable, vdslLineExtMCMGroups=vdslLineExtMCMGroups, vdslLineMCMConfProfileMaxTxPSDRowStatus=vdslLineMCMConfProfileMaxTxPSDRowStatus, vdslLineExtMCMConformance=vdslLineExtMCMConformance, vdslLineExtMCMMib=vdslLineExtMCMMib, vdslExtMCMMIB=vdslExtMCMMIB, vdslLineMCMConfProfileTxPSDTable=vdslLineMCMConfProfileTxPSDTable)
